#!/bin/sh

# $Id: whizard-config.in 2022 2010-03-07 20:36:24Z cnspeckn $
#
# Relocate libtool library headers (.la files) to a new installation directory.
#
########################################################################
#
# Copyright (C) 1999-2015 by 
#     Wolfgang Kilian <kilian@physik.uni-siegen.de>
#     Thorsten Ohl <ohl@physik.uni-wuerzburg.de>
#     Juergen Reuter <juergen.reuter@desy.de>
#     with contributions from
#     Christian Speckner <cnspeckn@googlemail.com>
#
# WHIZARD is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by 
# the Free Software Foundation; either version 2, or (at your option)
# any later version.
#
# WHIZARD is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the 
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
#
########################################################################

usage() {
cat <<EOI
usage: libtool-relocate.sh [options]

Replaces libtool library references to the hardcoded installation directory 
by the actual directory containing the installation.

Available options:
   --prefix DIR    : directory actually containing the WHIZARD installation
   --libdir DIR    : directory actually containing the WHIZARD libraries
                     (--libdir overrides --prefix)
   --lhapdf DIR    : directory actually containing the LHAPDF library
EOI
exit
}

unset newprefix
unset newlibdir
unset lhapdf_libdir

while test -n "$1"; do
   case "$1" in
      "--prefix")
	 if test -n "$2"; then
	     shift
	     newprefix=$1
         else
             usage
         fi
         ;;
      "--libdir")
	 if test -n "$2"; then
	     shift
	     newlibdir=$1
         else
             usage
         fi
         ;;
      "--lhapdf")
	 if test -n "$2"; then
	     shift
	     lhapdf_libdir=$1
         else
             usage
         fi
         ;;
      "--help")
         usage
         ;;
      *)
	 usage
	 ;;
   esac
   shift
done

prefix=/opt/whizard/whizard-2.2.8
exec_prefix=${prefix}
libdir=${exec_prefix}/lib

if test -z "$newlibdir"; then
  newlibdir=${newprefix}/lib
fi

if test "$newlibdir" != "$libdir"; then
  echo "libtool-relocate: replacing $libdir by $newlibdir:"
fi
if test -n "$lhapdf_libdir"; then
  echo "libtool-relocate: setting LHAPDF directory to $lhapdf_libdir:"
fi

for f in `find $newlibdir -name "*.la"`; do
    echo "  $f"
    if test "$newlibdir" != "$libdir" -a -n "$lhapdf_libdir"; then
      sed -e "s|\([ ']\)$libdir|\1$newlibdir|g" \
          -e "s|\([ ']\)[^ ']*\(/libLHAPDF.la\)\([ ']\)|\1${lhapdf_libdir}\2\3|" \
          $f > $f.tmp
    elif test "$newlibdir" != "$libdir"; then
      sed -e "s|\([ ']\)$libdir|\1$newlibdir|g" \
          $f > $f.tmp
    elif test -n "$lhapdf_libdir"; then
      sed -e "s|\([ ']\)[^ ']*\(/libLHAPDF.la\)\([ ']\)|\1${lhapdf_libdir}\2\3|" \
          $f > $f.tmp
    fi
    cp -f $f.tmp $f;
    rm -f $f.tmp
done
echo "done."
